@@ -20,6 +20,8 @@ from tests.test_data.results_provider_test_data import (
     TEST_GET_SUITE_ID_SINGLE_SUITE_MODE_BASELINES_IDS,
     TEST_REVERT_FUNCTIONS_AND_EXPECTED,
     TEST_REVERT_FUNCTIONS_IDS,
+    TEST_REVERT_FUNCTIONS_AND_EXPECTED_EXISTING_SUITE,
+    TEST_REVERT_FUNCTIONS_IDS_EXISTING_SUITE,
 )
 from trcli.api.api_request_handler import ProjectData
 from trcli.api.results_uploader import ResultsUploader
@@ -179,7 +181,7 @@ class TestResultsUploader:
         ), f"Expected exit code {exit_code}, but got {exception.value.code} instead."
 
     @pytest.mark.parametrize(
-        "run_id", [None, 10], ids=["No run ID provided", "Run ID provided"]
+        "run_id", [None, 101], ids=["No run ID provided", "Run ID provided"]
     )
     @pytest.mark.results_uploader
     def test_upload_results_successful(
@@ -205,17 +207,23 @@ class TestResultsUploader:
         )
         results_uploader.api_request_handler.check_automation_id_field.return_value = None
         results_uploader.api_request_handler.check_missing_test_cases_ids.return_value = ([], "")
+        results_uploader.api_request_handler.delete_sections.return_value = ([], "")
         expected_log_calls = []
         if not run_id:
             calls = {
-                2: mocker.call("Creating test run. ", new_line=False),
-                3: mocker.call("Run created: https://fake_host.com/index.php?/runs/view/100"),
-                4: mocker.call("Closing test run. ", new_line=False),
+                2: mocker.call("Removing unnecessary empty sections that may have been created earlier. ", new_line=False),
+                3: mocker.call("Removed 1 unused/empty section(s)."),
+                4: mocker.call("Creating test run. ", new_line=False),
+                5: mocker.call("Test run: https://fake_host.com/index.php?/runs/view/100"),
+                6: mocker.call("Closing test run. ", new_line=False),
             }
         else:
             calls = {
-                2: mocker.call("Updating run: https://fake_host.com/index.php?/runs/view/10"),
-                3: mocker.call("Closing test run. ", new_line=False),
+                2: mocker.call("Removing unnecessary empty sections that may have been created earlier. ", new_line=False),
+                3: mocker.call("Removed 1 unused/empty section(s)."),
+                4: mocker.call("Updating test run. ", new_line=False),
+                5: mocker.call("Test run: https://fake_host.com/index.php?/runs/view/101"),
+                6: mocker.call("Closing test run. ", new_line=False),
             }
 
         results_uploader.upload_results()
@@ -223,6 +231,7 @@ class TestResultsUploader:
             assert environment.log.call_args_list[index] == call
 
 
+    # TODO: review this test; shouldnt it use a suite_id > 0?
     @pytest.mark.results_uploader
     def test_get_suite_id_returns_valid_id(self, result_uploader_data_provider):
         """The purpose of this test is to check that get_suite_id function will
@@ -239,13 +248,16 @@ class TestResultsUploader:
             suite_id
         )
         results_uploader.api_request_handler.check_suite_id.return_value = (True, "")
-        (result_suite_id, result_return_code,) = results_uploader.get_suite_id(
+        (result_suite_id, result_return_code, suite_added) = results_uploader.get_suite_id(
             project_id=project_id, suite_mode=SuiteModes.single_suite
         )
 
         assert (
             result_suite_id == suite_id
         ), f"Expected suite_id: {suite_id} but got {result_suite_id} instead."
+        assert (
+            suite_added == False
+        ), f"Expected suite_added: {False} but got {suite_added} instead."
         assert (
             result_return_code == result_code
         ), f"Expected suite_id: {result_code} but got {result_return_code} instead."
@@ -298,7 +310,7 @@ class TestResultsUploader:
         results_uploader.api_request_handler.suites_data_from_provider.suite_id = None
         results_uploader.api_request_handler.suites_data_from_provider.name = suite_name
         environment.get_prompt_response_for_auto_creation.return_value = user_response
-        result_suite_id, result_code = results_uploader.get_suite_id(
+        result_suite_id, result_code, suite_added = results_uploader.get_suite_id(
             project_id, suite_mode
         )
         expected_elog_calls = []
@@ -368,7 +380,7 @@ class TestResultsUploader:
         expected_elog_calls = []
         if error_message:
             expected_elog_calls = [mocker.call(error_message)]
-        result_suite_id, result_code = results_uploader.get_suite_id(
+        result_suite_id, result_code, suite_added = results_uploader.get_suite_id(
             project_id, suite_mode
         )
 
@@ -413,7 +425,7 @@ class TestResultsUploader:
         expected_elog_calls = []
         if expected_error_message:
             expected_elog_calls = [mocker.call(expected_error_message)]
-        result_suite_id, result_code = results_uploader.get_suite_id(
+        result_suite_id, result_code, suite_added = results_uploader.get_suite_id(
             project_id, suite_mode
         )
 
@@ -446,7 +458,7 @@ class TestResultsUploader:
                 FAULT_MAPPING["unknown_suite_mode"].format(suite_mode=suite_mode)
             )
         ]
-        result_suite_id, result_code = results_uploader.get_suite_id(
+        result_suite_id, result_code, suite_added = results_uploader.get_suite_id(
             project_id, suite_mode
         )
 
@@ -793,5 +805,45 @@ class TestResultsUploader:
         )
 
         assert (
-            results_uploader.rollback_changes(1, [1, 2], [1, 2], 2) == expected_result
+            results_uploader.rollback_changes(1, True, [1, 2], [1, 2], 2) == expected_result
         ), "Revert process not completed as expected in test."
+
+
+    @pytest.mark.results_uploader
+    @pytest.mark.parametrize(
+        "failing_function, expected_result",
+        TEST_REVERT_FUNCTIONS_AND_EXPECTED_EXISTING_SUITE,
+        ids=TEST_REVERT_FUNCTIONS_IDS_EXISTING_SUITE,
+    )
+    def test_rollback_changes_after_error_doesnt_delete_existing_suite(
+        self, result_uploader_data_provider, failing_function, expected_result, mocker
+    ):
+        """The purpose of this test is to check that if rollback behave properly
+        when the suite already exists and thus cannot be deleted"""
+        (
+            environment,
+            api_request_handler,
+            results_uploader,
+        ) = result_uploader_data_provider
+
+        results_uploader.project = ProjectData(
+            project_id=1,
+            suite_mode=SuiteModes.multiple_suites,
+            error_message=""
+        )
+
+        suite_id = 1234
+        results_uploader.api_request_handler.suites_data_from_provider.suite_id = (
+            suite_id
+        )
+        results_uploader.api_request_handler.check_suite_id.return_value = (True, "")
+
+        api_request_handler_delete_mocker(
+            results_uploader=results_uploader,
+            mocker=mocker,
+            failing_functions=[failing_function],
+        )
+
+        assert (
+            results_uploader.rollback_changes(suite_id, False, [1, 2], [1, 2], 2) == expected_result
+        ), "Revert process not completed as expected in test."
\ No newline at end of file
