@@ -1,7 +1,6 @@
-import json
 import os
 import sys
-from typing import List, Union
+from beartype.typing import List, Union
 
 import click
 import yaml
@@ -16,6 +15,7 @@ from trcli.constants import (
     MISSING_COMMAND_SLOGAN,
     TOOL_USAGE,
     TOOL_VERSION,
+    PARSE_JUNIT_OR_ROBOT_FAULT_MAPPING,
 )
 from trcli.data_classes.data_parsers import FieldsParser
 from trcli.settings import DEFAULT_API_CALL_TIMEOUT, DEFAULT_BATCH_SIZE
@@ -27,7 +27,8 @@ cmd_folder = trcli_folder / "commands/"
 
 
 class Environment:
-    def __init__(self):
+    def __init__(self, cmd="parse_junit"):
+        self.cmd = cmd
         self.home = os.getcwd()
         self.default_config_file = True
         self.params_from_config = dict()
@@ -45,8 +46,12 @@ class Environment:
         self.batch_size = None
         self.timeout = None
         self.suite_id = None
+        self.suite_name = None
         self.run_id = None
+        self.plan_id = None
+        self.config_ids = None
         self.milestone_id = None
+        self.section_id = None
         self.auto_creation_response = None
         self.silent = None
         self.close_run = None
@@ -141,6 +146,11 @@ class Environment:
             if "missing_" + param in FAULT_MAPPING and not value:
                 self.elog(FAULT_MAPPING["missing_" + param])
                 exit(1)
+            if (self.cmd == "parse_junit" or self.cmd == "parse_robot") and "missing_" + param in PARSE_JUNIT_OR_ROBOT_FAULT_MAPPING and not value:
+                # If we have empty title, check for run_id
+                if (param == "title" and not self.run_id):
+                    self.elog(PARSE_JUNIT_OR_ROBOT_FAULT_MAPPING["missing_" + param])
+                    exit(1)
         # special case for password and key (both needs to be missing for the error message to show up)
         if not self.password and not self.key:
             self.elog(FAULT_MAPPING["missing_password_and_key"])
@@ -227,6 +237,10 @@ class TRCLI(click.MultiCommand):
             return
         return mod.cli
 
+    def main(self, *args, **kwargs):
+        """Overriding to disable automatic glob patterns expansion"""
+        return super().main(windows_expand_args=False, *args, **kwargs)
+
 
 @click.command(cls=TRCLI, context_settings=CONTEXT_SETTINGS)
 @click.pass_context
