@@ -1,17 +1,19 @@
+import glob
 from pathlib import Path
-from typing import Union
+from beartype.typing import Union, List
 from unittest import TestCase, TestSuite
 from xml.etree import ElementTree as etree
 
 from junitparser import JUnitXml, JUnitXmlError, Element, Attr
 
-from trcli.data_classes.data_parsers import MatchersParser, FieldsParser
+from trcli.cli import Environment
+from trcli.data_classes.data_parsers import MatchersParser, FieldsParser, TestRailCaseFieldsOptimizer
 from trcli.data_classes.dataclass_testrail import (
     TestRailCase,
     TestRailSuite,
     TestRailSection,
     TestRailProperty,
-    TestRailResult,
+    TestRailResult, TestRailSeparatedStep,
 )
 from trcli.readers.file_parser import FileParser
 
@@ -31,6 +33,12 @@ class Property(Element):
 
 
 class JunitParser(FileParser):
+
+    def __init__(self, environment: Environment):
+        super().__init__(environment)
+        self.case_matcher = environment.case_matcher
+        self.special = environment.special_parser
+
     @classmethod
     def _add_root_element_to_tree(cls, filepath: Union[str, Path]) -> etree:
         """
@@ -48,7 +56,26 @@ class JunitParser(FileParser):
         else:
             raise JUnitXmlError("Invalid format.")
 
-    def parse_file(self) -> list[TestRailSuite]:
+    @staticmethod
+    def check_file(filepath: Union[str, Path]) -> Path:
+        filepath = Path(filepath)
+        files = glob.glob(str(filepath))
+        if not files:
+            raise FileNotFoundError("File not found.")
+        elif len(files) == 1:
+            return filepath
+        sub_suites = []
+        for file in files:
+            suite = JUnitXml.fromfile(file)
+            sub_suites.append(suite)
+        suite = sub_suites.pop(0)
+        for sub_suite in sub_suites:
+            suite += sub_suite
+        merged_report_path = Path().cwd().joinpath("Merged-JUnit-report.xml")
+        suite.write(merged_report_path)
+        return merged_report_path
+
+    def parse_file(self) -> List[TestRailSuite]:
         self.env.log(f"Parsing JUnit report.")
         suite = JUnitXml.fromfile(
             self.filepath, parse_func=self._add_root_element_to_tree
@@ -63,7 +90,7 @@ class JunitParser(FileParser):
 
         for suite in suites:
             if suite.name:
-                self.env.log(f"Processing suite - {suite.name}")
+                self.env.log(f"Processing JUnit suite - {suite.name}")
             cases_count = 0
             test_sections = []
             processed_section_properties = []
@@ -84,6 +111,7 @@ class JunitParser(FileParser):
                     result_fields = []
                     case_fields = []
                     comments = []
+                    result_steps = []
                     sauce_session = None
                     automation_id = f"{case.classname}.{case_name}"
                     if self.case_matcher == MatchersParser.NAME:
@@ -92,6 +120,17 @@ class JunitParser(FileParser):
                         for prop in case_props.iterchildren(Property):
                             if prop.name and self.case_matcher == MatchersParser.PROPERTY and prop.name == "test_id":
                                 case_id = int(prop.value.lower().replace("c", ""))
+                            if prop.name and prop.name.startswith("testrail_result_step"):
+                                status, step = prop.value.split(':', maxsplit=1)
+                                step = TestRailSeparatedStep(step.strip())
+                                status_dict = {
+                                    "passed": 1,
+                                    "untested": 3,
+                                    "skipped": 4,
+                                    "failed": 5
+                                }
+                                step.status_id = status_dict[status.lower().strip()]
+                                result_steps.append(step)
                             if prop.name and prop.name.startswith("testrail_attachment"):
                                 attachments.append(prop.value)
                             if prop.name and prop.name.startswith("testrail_result_field"):
@@ -115,7 +154,8 @@ class JunitParser(FileParser):
                         elapsed=case.time,
                         junit_result_unparsed=case.result,
                         attachments=attachments,
-                        result_fields=result_fields_dict
+                        result_fields=result_fields_dict,
+                        custom_step_results=result_steps
                     )
                     for comment in reversed(comments):
                         result.prepend_comment(comment)
@@ -123,13 +163,14 @@ class JunitParser(FileParser):
                         result.prepend_comment(f"SauceLabs session: {sauce_session}")
                     test_cases.append(
                         TestRailCase(
-                            title=case_name,
+                            title=TestRailCaseFieldsOptimizer.extract_last_words(case_name, TestRailCaseFieldsOptimizer.MAX_TESTCASE_TITLE_LENGTH),
                             case_id=case_id,
                             result=result,
                             custom_automation_id=automation_id,
                             case_fields=case_fields_dict
                         )
                     )
+                self.env.log("Processed {0} test cases in section {1}.".format(len(test_cases), section.name))
                 test_sections.append(
                     TestRailSection(
                         section.name,
@@ -137,10 +178,9 @@ class JunitParser(FileParser):
                         properties=properties,
                     )
                 )
-            self.env.log(f"Processed {cases_count} test cases in {len(test_sections)} sections.")
             testrail_suites.append(
                 TestRailSuite(
-                    suite.name,
+                    self.env.suite_name if self.env.suite_name else suite.name,
                     testsections=test_sections,
                     source=self.filename,
                 )
@@ -148,7 +188,7 @@ class JunitParser(FileParser):
 
         return testrail_suites
 
-    def split_sauce_report(self, suite) -> list[JUnitXml]:
+    def split_sauce_report(self, suite) -> List[JUnitXml]:
         self.env.log(f"Processing SauceLabs report.")
         subsuites = {}
         for section in suite:
